import numpy as np
import pandas as pd
import matplotlib.pyplot as plt
from matplotlib.ticker import MultipleLocator
from matplotlib import cm
from matplotlib.ticker import FuncFormatter
from pylab import *

#var represent different ligand
#... represent file pathway

var_complex_area = np.loadtxt(r'...\var-complex-90-area.xvg', comments = ['#','@'], encoding = 'UTF-8')
var_pro_area = np.loadtxt(r'...\var-pro-90-area.xvg', comments = ['#','@'], encoding = 'UTF-8')
var_lig_area = np.loadtxt(r'...\var-lig-90-area.xvg', comments = ['#','@'], encoding = 'UTF-8')
var_ir_rmsd = np.loadtxt(r'...\var-ligir-rmsd.xvg', comments = ['#','@'], encoding = 'UTF-8')

var_area = []
for i in range(len(var_complex_area[:,1])):
    var_area.append(var_pro_area[i,1] + var_lig_area[i,1] - var_complex_area[i,1])
    
rc('font', family='Times New Roman')

cmap = cm.colors.LinearSegmentedColormap.from_list('new_map',[cm.nipy_spectral(i) for i in range(0,256,1)]+[('white')],19)
fig, ax = plt.subplots(figsize=(8,6), dpi=1200)

font1 = {'family':'Times New Roman',
         'weight':'normal',
         'size':'18'}
font2 = {'family':'Times New Roman',
         'weight':'normal',
         'size':'20'}
font3 = {'family':'Times New Roman',
         'size':'18'}

z, xedge, yedge = np.histogram2d(np.array(var_area), var_ir_rmsd[:,1], bins=60,range=[[5,11], [0.0, 0.5]])
x = 0.5*(xedge[:-1] + xedge[1:])
y = 0.5*(yedge[:-1] + yedge[1:])

zmin_nonzero = np.min(z[np.where(z > 0)])
z = np.maximum(z, zmin_nonzero)
F = -2.479 * np.log(z)
F -= np.max(F)
F = np.minimum(F, 0)

extent = [yedge[0], yedge[-1], xedge[0], xedge[-1]]
plt.contourf(x, y, F.T, 200, cmap=cmap,extent=extent,levels=[i for i in range(-19,0,1)]+[0] )

labels = ax.get_xticklabels() + ax.get_yticklabels()
for label in labels:
    label.set_fontname('Times New Roman') 
        
plt.tick_params(which="major", labelsize=18,direction='out',width=1.5, length=5)
plt.tick_params(which="minor", labelsize=18,direction='out',width=1.5, length=3)

ax.spines["left"].set_linewidth(1.5)
ax.spines["right"].set_linewidth(1.5)
ax.spines["top"].set_linewidth(1.5)
ax.spines["bottom"].set_linewidth(1.5)

ax.xaxis.set_major_locator(MultipleLocator(1))
ax.xaxis.set_minor_locator(MultipleLocator(0.5))
ax.yaxis.set_major_locator(MultipleLocator(0.1))
ax.yaxis.set_minor_locator(MultipleLocator(0.05))

clb = plt.colorbar()
clb.set_ticks([i for i in range(-19,1,1)][::-2])
clb.ax.tick_params(labelsize=16,width=1.5)
clb.set_label("\nFree energy  (kJ/mol)", fontdict=font1)

xlim(5,11)
ylim(0.0,0.5)

ax.set_xlabel('Buried surface area  (nm$^\mathregular{2}$)',font2)
ax.set_ylabel('iRMSD  (nm)',font2)
font4 = {'family':'Times New Roman',
          'size':'16',
         'color':'k'}
plt.savefig('var_fig.png')
plt.tight_layout()
